@@ -5,6 +5,7 @@ import time
 import fnmatch
 import tempfile
 
+
 def snip_dir(source_dir,  # Sources
              dest_dir=None,  # Will write to this directory
              output_dir=None, # Where snippets are going to be stored
@@ -15,6 +16,7 @@ def snip_dir(source_dir,  # Sources
              license_head=None,
              ):
 
+
     if dest_dir == None:
         dest_dir = tempfile.mkdtemp()
         print("[snipper]", "no destination dir was specified so using nonsense destination:", dest_dir)
@@ -52,46 +54,22 @@ def snip_dir(source_dir,  # Sources
     shutil.copytree(source_dir, dest_dir)
     time.sleep(0.1)
 
-    ls = list(Path(dest_dir).glob('**/*.*'))
+    ls = list(Path(dest_dir).glob('**/*'))
     acceptable = []
     for l in ls:
         split = os.path.normpath(os.path.relpath(l, dest_dir))
         m = [fnmatch.fnmatch(split, ex) for ex in exclude]
         acceptable.append( (l, not any(m) ))
 
-    # for f,ac in acceptable:
-    #     if not ac:
-    #         print(f)
-
-    # print(acceptable)
-    # now we have acceptable files in list.
-    # run_out_dirs = ["./output"]
     n = 0
-    # edirs = [os.path.join(out, f_) for f_ in hw['exclusion']]  # Exclude directories on exclude list (speed)
-    # edirs = {os.path.normpath(os.path.dirname(f_) if not os.path.isdir(f_) else f_) for f_ in edirs}
-    # edirs.remove(os.path.normpath(out))
     for f, accept in acceptable:
-        if os.path.isdir(f) or not str(f).endswith(".py") or  str(f).endswith("_grade.py"): # We only touch .py files.
+        if os.path.isdir(f) or not str(f).endswith(".py") or  str(f).endswith("_grade.py"):
             continue
-        # f_dir = os.path.normpath(f if os.path.isdir(f) else os.path.dirname(f))
         if accept:
-            # slist = hw['solutions'] if not CE else [os.path.basename(f)[:-3]]
-            # base = None
-            # if students_irlc_tools is not None:
-            #     base = os.path.relpath(str(f), students_irlc_tools + "/..")
-            #     base = base.replace("\\", "/")
-
-            # if "assignments" in str(f) and "_grade.py" in str(f):
-            #     continue
-            # info = {'new_references': [], 'code_copyright': 'Example student code. This file is automatically generated from the files in the instructor-directory'}
-            # paths = {}
             solution_list = []
             kwargs = {}
-            # cut_files = True
-            # copyright()
-
-            # run_files = True
-            nrem = censor_file(f, run_files=run_files, run_out_dirs=output_dir, cut_files=cut_files, solution_list=solution_list,
+            nrem = censor_file(f, run_files=run_files, run_out_dirs=output_dir, cut_files=cut_files,
+                               solution_list=solution_list,
                                base_path=dest_dir,
                                references=references,
                                license_head=license_head,
@@ -105,7 +83,6 @@ def snip_dir(source_dir,  # Sources
             if os.path.isfile(rm_file):
                 os.remove(rm_file)
             else:
-                if os.path.isdir(rm_file + "\\"):
+                if os.path.isdir(rm_file+"/"):
                     shutil.rmtree(rm_file)
-
     return n
