@@ -22,8 +22,8 @@ def rem_nonprintable_ctrl_chars(txt):
 
 def censor_code(lines, keep=True):
     dbug = True
-    lines = fix_f(lines, dbug)
-    lines, nB, cut = fix_b(lines, keep=True)
+    lines = fix_f(lines, dbug, keep=keep)
+    lines, nB, cut = fix_b(lines, keep=keep)
     return lines
 
 
